Package: nlpsem
Type: Package
Title: Nonlinear Longitudinal Process in Structural Equation Modeling
Version: 0.4
Authors@R: c(person(given = "Jin",
           family = "Liu",
           role = c("aut", "cre"),
           email = "Veronica.Liu0206@gmail.com"))
Description: Provides computational tools for nonlinear longitudinal models, in particular the intrinsically nonlinear models, in four scenarios: (1) univariate longitudinal processes with growth factors, with or without covariates including time-invariant covariates (TICs) and time-varying covariates (TVCs); (2) multivariate longitudinal processes that facilitate the assessment of correlation or causation between multiple longitudinal variables; (3) multiple-group models for scenarios (1) and (2) to evaluate differences among manifested groups, and (4) longitudinal mixture models for scenarios (1) and (2), with an assumption that trajectories are from multiple latent classes. The methods implemented are introduced in Liu (2025) <doi:10.3758/s13428-025-02596-4>.
License: GPL (>= 3)
Encoding: UTF-8
LazyData: true
Depends: R (>= 4.0.0), OpenMx (>= 2.21.8)
Imports: ggplot2, dplyr, tidyr, stringr, Matrix, nnet, readr, methods,
        grDevices, stats, utils
RoxygenNote: 7.3.3
URL: https://github.com/Veronica0206/nlpsem
BugReports: https://github.com/Veronica0206/nlpsem/issues
Suggests: testthat (>= 3.0.0), knitr, rmarkdown
VignetteBuilder: knitr
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-03-25 23:53:24 UTC; veronica
Author: Jin Liu [aut, cre]
Maintainer: Jin Liu <Veronica.Liu0206@gmail.com>
Repository: CRAN
Date/Publication: 2026-03-31 16:20:02 UTC
Built: R 4.6.0; ; 2026-04-29 22:59:07 UTC; unix
